@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU General Public License
    along with LibGTop; see the file COPYING. If not, write to the
-   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
 */
 
 #include <config.h>
@@ -27,12 +27,11 @@ void
 handle_slave_connection (int input, int output)
 {
 	glibtop *server G_GNUC_UNUSED = glibtop_global_server;
+	gint64 *param_ptr G_GNUC_UNUSED;
 	const void *ptr G_GNUC_UNUSED;
 
 	unsigned short max_len G_GNUC_UNUSED;
 	pid_t pid G_GNUC_UNUSED;
-	gint64 proc_which G_GNUC_UNUSED;
-	gint64 proc_arg G_GNUC_UNUSED;
 
 	glibtop_response _resp, *resp = &_resp;
 	glibtop_command _cmnd, *cmnd = &_cmnd;
@@ -41,8 +40,10 @@ handle_slave_connection (int input, int output)
 	glibtop_send_version (glibtop_global_server, output);
 
 	while (do_read (input, cmnd, sizeof (glibtop_command))) {
-		glibtop_debug ("Slave %d received command "
-			 "%llu from client.", getpid (), cmnd->command);
+#ifdef SLAVE_DEBUG
+		fprintf (stderr, "Slave %d received command "
+			 "%llu from client.\n", getpid (), cmnd->command);
+#endif
 
 		if (cmnd->data_size >= BUFSIZ)
 			glibtop_error ("Client sent %llu bytes, "
@@ -54,8 +55,10 @@ handle_slave_connection (int input, int output)
 		memset (parameter, 0, sizeof (parameter));
 
 		if (cmnd->data_size) {
-			glibtop_debug ("Client has %llu bytes of data.",
+#ifdef SLAVE_DEBUG
+			fprintf (stderr, "Client has %llu bytes of data.\n",
 				 cmnd->data_size);
+#endif
 
 			do_read (input, parameter, cmnd->data_size);
 
@@ -69,11 +72,10 @@ handle_slave_connection (int input, int output)
 			return;
 #if GLIBTOP_SUID_PROCLIST
 		case GLIBTOP_CMND_PROCLIST:
-			memcpy(&proc_which, parameter, sizeof proc_which);
-			memcpy(&proc_arg, parameter + sizeof proc_which, sizeof proc_arg);
+			param_ptr = (gint64 *) parameter;
 			ptr = glibtop_get_proclist_p
 				(server, &resp->u.data.proclist,
-				 proc_which, proc_arg);
+				 param_ptr [0], param_ptr [1]);
 			do_output (output, resp, _offset_data (proclist),
 				   resp->u.data.proclist.total, ptr);
 			g_free (ptr);
@@ -209,14 +211,6 @@ handle_slave_command (glibtop_command *cmnd, glibtop_response *resp,
 		resp->offset = _offset_data (proc_time);
 		break;
 #endif
-#if GLIBTOP_SUID_PROC_IO
-	case GLIBTOP_CMND_PROC_IO:
-		memcpy (&pid, parameter, sizeof (pid_t));
-		glibtop_get_proc_io_p
-			(server, &resp->u.data.proc_io, pid);
-		resp->offset = _offset_data (proc_time);
-		break;
-#endif
 #if GLIBTOP_SUID_PROC_SIGNAL
 	case GLIBTOP_CMND_PROC_SIGNAL:
 		memcpy (&pid, parameter, sizeof (pid_t));
