@@ -1,3 +1,5 @@
+/* $OpenBSD: procuid.c,v 1.3 2011/05/23 19:35:56 jasper Exp $	*/
+
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -15,8 +17,8 @@
 
    You should have received a copy of the GNU General Public License
    along with LibGTop; see the file COPYING. If not, write to the
-   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
 */
 
 #include <config.h>
@@ -52,7 +54,7 @@ void
 glibtop_get_proc_uid_p (glibtop *server, glibtop_proc_uid *buf,
 			pid_t pid)
 {
-	struct kinfo_proc *pinfo;
+	struct kinfo_proc2 *pinfo;
 	int count = 0;
 
 	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROC_UID), 0);
@@ -63,9 +65,9 @@ glibtop_get_proc_uid_p (glibtop *server, glibtop_proc_uid *buf,
 	if (pid == 0) return;
 
 	/* Get the process information */
-	pinfo = kvm_getprocs (server->machine->kd, KERN_PROC_PID, pid,
+	pinfo = kvm_getproc2 (server->machine.kd, KERN_PROC_PID, pid,
 			      sizeof (*pinfo), &count);
-	if (pinfo == NULL) {
+	if ((pinfo == NULL) || (count != 1)) {
 		glibtop_warn_io_r (server, "kvm_getprocs (%d)", pid);
 		return;
 	}
